import 'package:gui_app/provider.dart';
import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:scroll_to_index/scroll_to_index.dart';
import 'package:flutter_gen/gen_l10n/app_localizations.dart';
import 'package:gui_app/const/colors.dart';
import 'package:gui_app/const/dimens.dart';

class Log extends ConsumerStatefulWidget {
  final double width;
  final double height;
  const Log(
      {Key? key, this.width = double.infinity, this.height = double.infinity})
      : super(key: key);
  @override
  ConsumerState<Log> createState() {
    return _LogState();
  }
}

class _LogState extends ConsumerState<Log> {
  final _controller = AutoScrollController();
  @override
  Widget build(BuildContext context) {
    final Size containerSize = MediaQuery.of(context).size;
    return SizedBox(
      width: widget.width,
      height: widget.height,
      child: Column(
        children: [
          Text(
            L10n.of(context)!.alertLog,
            style: TextStyle(
                fontSize: containerSize.width * logTitleFontSizeRatio,
                color: textColor),
          ),
          Expanded(
            child: Container(
              color: logBackgroundColor,
              child: RawScrollbar(
                controller: _controller,
                thumbColor: scrollBarColor,
                thumbVisibility: true,
                child: ListView.builder(
                  controller: _controller,
                  reverse: true,
                  itemCount: ref.watch(alertLogProvider).length,
                  itemBuilder: (context, index) => _buildCard(index),
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }

  Widget _buildCard(int index) {
    final Size containerSize = MediaQuery.of(context).size;
    _controller.scrollToIndex(ref.watch(alertLogProvider).length);
    return AutoScrollTag(
      key: ValueKey(index),
      controller: _controller,
      index: index,
      child: Card(
        color: logBackgroundColor,
        child: Text(
          ref.watch(alertLogProvider)[index] +
              ' ' +
              L10n.of(context)!.alertMessage,
          style: TextStyle(
              fontSize: containerSize.width * logTitleFontSizeRatio,
              color: textColor),
        ),
      ),
    );
  }
}
